summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMarcello Stanisci <marcello.stanisci@inria.fr>2017-05-02 09:33:48 +0200
committerMarcello Stanisci <marcello.stanisci@inria.fr>2017-05-02 09:33:48 +0200
commitdfc0e823a16bc0ac62ed5d29469f96efeefdf9bb (patch)
tree160a9f5c9c24d7125c957455de7f502ef0c80a71
parent2607c6138ccec953f9ad5263f56bf514259d94b4 (diff)
downloadmerchant-dfc0e823a16bc0ac62ed5d29469f96efeefdf9bb.tar.gz
merchant-dfc0e823a16bc0ac62ed5d29469f96efeefdf9bb.tar.bz2
merchant-dfc0e823a16bc0ac62ed5d29469f96efeefdf9bb.zip
Addressing #4877
-rw-r--r--src/backend/taler-merchant-httpd_pay.c10
-rw-r--r--src/backenddb/plugin_merchantdb_postgres.c6
2 files changed, 8 insertions, 8 deletions
diff --git a/src/backenddb/plugin_merchantdb_postgres.c b/src/backenddb/plugin_merchantdb_postgres.c
index 0f2ed732..e5124bbc 100644
--- a/src/backenddb/plugin_merchantdb_postgres.c
+++ b/src/backenddb/plugin_merchantdb_postgres.c
@@ -450,7 +450,7 @@ postgres_initialize (void *cls)
* @param proposal_data where to store the retrieved proposal data
* @param h_proposal_data proposal data's hashcode that will be used to
* perform the lookup
- * @return #GNUNET_OK on success, #GNUNET_NO if no contract is
+ * @return #GNUNET_OK on success, #GNUNET_NO if no proposal is
* found, #GNUNET_SYSERR upon error
*/
static int
@@ -508,7 +508,7 @@ postgres_find_proposal_data_from_hash (void *cls,
* @param cls closure
* @param proposal_data where to store the retrieved proposal data
* @param order id order id used to perform the lookup
- * @return #GNUNET_OK on success, #GNUNET_NO if no contract is
+ * @return #GNUNET_OK on success, #GNUNET_NO if no proposal is
* found, #GNUNET_SYSERR upon error
*/
static int
@@ -600,7 +600,7 @@ postgres_insert_proposal_data (void *cls,
/**
* We don't treat a unique_violation (code '23505') error as
* an actual error, since there is no problem if a frontend tries
- * to store twice the same contract. That is especially needed
+ * to store twice the same proposal. That is especially needed
* when DB-less frontends perform replayed payments.
*/
if (PGRES_COMMAND_OK != PQresultStatus (result)
diff --git a/src/backend/taler-merchant-httpd_pay.c b/src/backend/taler-merchant-httpd_pay.c
index 8e835f18..5c23f138 100644
--- a/src/backend/taler-merchant-httpd_pay.c
+++ b/src/backend/taler-merchant-httpd_pay.c
@@ -209,12 +209,12 @@ struct PayContext
struct GNUNET_TIME_Absolute refund_deadline;
/**
* Deadline for the customer to pay for this contract.
*/
struct GNUNET_TIME_Absolute pay_deadline;
/**
- * "H_contract" from @e proposal_data.
+ * Hashed proposal.
*/
struct GNUNET_HashCode h_proposal_data;
@@ -856,7 +856,7 @@ handle_pay_timeout (void *cls)
* Function called with information about a coin that was deposited.
*
* @param cls closure
- * @param transaction_id of the contract
+ * @param h_proposal_data hashed proposal data
* @param coin_pub public key of the coin
* @param amount_with_fee amount the exchange will deposit for this coin
* @param deposit_fee fee the exchange will charge for this coin
@@ -910,9 +910,9 @@ check_coin_paid (void *cls,
* Update `transaction_exists` accordingly.
*
* @param cls closure with the `struct PayContext`
- * @param transaction_id of the contract
* @param merchant_pub merchant's public key
* @param exchange_uri URI of the exchange
+ * @param h_proposal_data hashed proposal data
* @param h_xwire hash of our wire details
* @param timestamp time of the confirmation
* @param refund refund deadline
@@ -1041,7 +1041,7 @@ parse_pay (struct MHD_Connection *connection,
if (MHD_YES !=
TMH_RESPONSE_reply_internal_error (connection,
TALER_EC_PAY_MERCHANT_FIELD_MISSING,
- "No merchant field in contract"))
+ "No merchant field in proposal"))
{
GNUNET_break (0);
return GNUNET_SYSERR;
@@ -209,12 +209,12 @@ struct PayContext
struct GNUNET_TIME_Absolute refund_deadline;
/**
- * Deadline for the customer to pay for this contract.
+ * Deadline for the customer to pay for this proposal.
*/
struct GNUNET_TIME_Absolute pay_deadline;